<?php

namespace Lavalite\Career\Http\Controllers;

use App\Http\Controllers\AdminController as AdminController;
use Former;
use Lavalite\Career\Http\Requests\JobAdminRequest;
use Lavalite\Career\Interfaces\JobRepositoryInterface;
use Response;

/**
 * Admin controller class.
 */
class JobAdminController extends AdminController
{
    /**
     * Initialize job controller.
     *
     * @param type JobRepositoryInterface $job
     *
     * @return type
     */
    public function __construct(JobRepositoryInterface $job)
    {
        $this->model = $job;
        parent::__construct();
    }

    /**
     * Display a listing of the resource.
     *
     * @return Response
     */
    public function index(JobAdminRequest $request)
    {
        if ($request->wantsJson()) {
            $array = $this->model->json();
            foreach ($array as $key => $row) {
                $array[$key] = array_only($row, config('career.job.listfields'));
            }

            return ['data' => $array];
        }

        $this->theme->prependTitle(trans('career::job.names').' :: ');

        return $this->theme->of('career::admin.job.index')->render();
    }

    /**
     * Display the specified resource.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function show(JobAdminRequest $request, $id)
    {
        $job = $this->model->find($id);

        if (empty($job)) {
            if ($request->wantsJson()) {
                return [];
            }

            return view('career::admin.job.new');
        }

        if ($request->wantsJson()) {
            return $job;
        }

        Former::populate($job);

        return view('career::admin.job.show', compact('job'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(JobAdminRequest $request)
    {
        $job = $this->model->findOrNew(0);
        Former::populate($job);

        return view('career::admin.job.create', compact('job'));
    }

    /**
     * Display the specified resource.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(JobAdminRequest $request)
    {
        try {
            $attributes = $request->all();
            $job = $this->model->create($attributes);

            return $this->success(trans('messages.success.created', ['Module' => trans('career::job.name')]));
        } catch (Exception $e) {
            return $this->error($e->getMessage());
        }
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function edit(JobAdminRequest $request, $id)
    {
        $job = $this->model->find($id);

        Former::populate($job);

        return view('career::admin.job.edit', compact('job'));
    }

    /**
     * Update the specified resource.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function update(JobAdminRequest $request, $id)
    {
        try {
            $attributes = $request->all();
            $job = $this->model->update($attributes, $id);

            return $this->success(trans('messages.success.updated', ['Module' => trans('career::job.name')]));
        } catch (Exception $e) {
            return $this->error($e->getMessage());
        }
    }

    /**
     * Remove the specified resource.
     *
     * @param int $id
     *
     * @return Response
     */
    public function destroy(JobAdminRequest $request, $id)
    {
        try {
            $this->model->delete($id);

            return $this->success(trans('message.success.deleted', ['Module' => trans('career::job.name')]), 200);
        } catch (Exception $e) {
            return $this->error($e->getMessage());
        }
    }
}
