<?php

namespace Lavalite\Career\Http\Controllers;

use App\Http\Controllers\AdminController as AdminController;
use Former;
use Lavalite\Career\Http\Requests\ResumeAdminRequest;
use Lavalite\Career\Interfaces\ResumeRepositoryInterface;
use Response;

/**
 * Admin controller class.
 */
class ResumeAdminController extends AdminController
{
    /**
     * Initialize resume controller.
     *
     * @param type ResumeRepositoryInterface $resume
     *
     * @return type
     */
    public function __construct(ResumeRepositoryInterface $resume)
    {
        $this->model = $resume;
        parent::__construct();
    }

    /**
     * Display a listing of the resource.
     *
     * @return Response
     */
    public function index(ResumeAdminRequest $request)
    {
        if ($request->wantsJson()) {
            $array = $this->model->json();
            foreach ($array as $key => $row) {
                $array[$key] = array_only($row, config('career.resume.listfields'));
            }

            return ['data' => $array];
        }

        $this->theme->prependTitle(trans('career::resume.names').' :: ');

        return $this->theme->of('career::admin.resume.index')->render();
    }

    /**
     * Display the specified resource.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function show(ResumeAdminRequest $request, $id)
    {
        $resume = $this->model->find($id);

        if (empty($resume)) {
            if ($request->wantsJson()) {
                return [];
            }

            return view('career::admin.resume.new');
        }

        if ($request->wantsJson()) {
            return $resume;
        }

        Former::populate($resume);

        return view('career::admin.resume.show', compact('resume'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(ResumeAdminRequest $request)
    {
        $resume = $this->model->findOrNew(0);
        Former::populate($resume);

        return view('career::admin.resume.create', compact('resume'));
    }

    /**
     * Display the specified resource.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(ResumeAdminRequest $request)
    {
        try {
            $attributes = $request->all();
            $resume = $this->model->create($attributes);

            return $this->success(trans('messages.success.created', ['Module' => trans('career::resume.name')]));
        } catch (Exception $e) {
            return $this->error($e->getMessage());
        }
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function edit(ResumeAdminRequest $request, $id)
    {
        $resume = $this->model->find($id);

        Former::populate($resume);

        return view('career::admin.resume.edit', compact('resume'));
    }

    /**
     * Update the specified resource.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function update(ResumeAdminRequest $request, $id)
    {
        try {
            $attributes = $request->all();
            $resume = $this->model->update($attributes, $id);

            return $this->success(trans('messages.success.updated', ['Module' => trans('career::resume.name')]));
        } catch (Exception $e) {
            return $this->error($e->getMessage());
        }
    }

    /**
     * Remove the specified resource.
     *
     * @param int $id
     *
     * @return Response
     */
    public function destroy(ResumeAdminRequest $request, $id)
    {
        try {
            $this->model->delete($id);

            return $this->success(trans('message.success.deleted', ['Module' => trans('career::resume.name')]), 200);
        } catch (Exception $e) {
            return $this->error($e->getMessage());
        }
    }
}
