<?php

namespace Lavalite\Career\Http\Controllers;

use App\Http\Controllers\UserController as UserController;
use Former;
use Lavalite\Career\Http\Requests\ResumeUserRequest;
use Lavalite\Career\Interfaces\ResumeRepositoryInterface;
use Response;
use User;

class ResumeUserController extends UserController
{
    /**
     * Initialize resume controller.
     *
     * @param type ResumeRepositoryInterface $resume
     *
     * @return type
     */
    public function __construct(ResumeRepositoryInterface $resume)
    {
        $this->model = $resume;
        $this->model->setUserFilter();
        parent::__construct();
    }

    /**
     * Display a listing of the resource.
     *
     * @return Response
     */
    public function index(ResumeUserRequest $request)
    {
        $resumes = $this->model->all();

        $this->theme->prependTitle(trans('career::resume.names').' :: ');

        return $this->theme->of('career::user.resume.index', compact('resumes'))->render();
    }

    /**
     * Display the specified resource.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function show(ResumeUserRequest $request, $role, $id)
    {
        $resume = $this->model->find($id);

        return $this->theme->of('career::user.resume.show', compact('resume'))->render();
    }

    /**
     * Show the form for creating a new resource.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(ResumeUserRequest $request)
    {
        $resume = $this->model->findOrNew(0);

        Former::populate($resume);

        return $this->theme->of('career::user.resume.create', compact('resume'))->render();
    }

    /**
     * Display the specified resource.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(ResumeUserRequest $request)
    {
        try {
            $attributes = $request->all();
            $resume = $this->model->create($attributes);

            return $this->success(trans('messages.success.created', ['Module' => trans('career::resume.name')]));
        } catch (Exception $e) {
            return $this->error($e->getMessage());
        }
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function edit(ResumeUserRequest $request, $role, $id)
    {
        $resume = $this->model->find($id);

        Former::populate($resume);

        return $this->theme->of('career::user.resume.edit', compact('resume'))->render();
    }

    /**
     * Update the specified resource.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function update(ResumeUserRequest $request, $role, $id)
    {
        try {
            $attributes = $request->all();
            $resume = $this->model->update($attributes, $id);

            return $this->success(trans('messages.success.updated', ['Module' => trans('career::resume.name')]));
        } catch (Exception $e) {
            return $this->error($e->getMessage());
        }
    }

    /**
     * Remove the specified resource.
     *
     * @param int $id
     *
     * @return Response
     */
    public function destroy(ResumeUserRequest $request, $role, $id)
    {
        try {
            $this->model->delete($id);

            return $this->success(trans('message.success.deleted', ['Module' => trans('career::resume.name')]), 200);
        } catch (Exception $e) {
            return $this->error($e->getMessage());
        }
    }
}
