<?php

namespace Lavalite\Career\Http\Requests;

use App\Http\Requests\Request;
use User;

class JobAdminRequest extends Request
{
    /**
     * Determine if the user is authorized to make this request.
     *
     * @return bool
     */
    public function authorize(\Illuminate\Http\Request $request)
    {
        // Determine if the user is authorized to create an entry,
        if ($request->isMethod('POST') || $request->is('*/create')) {
            return User::can('career.job.create');
        }

        // Determine if the user is authorized to update an entry,
        if ($request->isMethod('PUT') || $request->isMethod('PATCH') || $request->is('*/edit')) {
            return User::can('career.job.edit');
        }

        // Determine if the user is authorized to delete an entry,
        if ($request->isMethod('DELETE')) {
            return User::can('career.job.delete');
        }

        // Determine if the user is authorized to view the module.
        return User::can('career.job.view');
    }

    /**
     * Get the validation rules that apply to the request.
     *
     * @return array
     */
    public function rules(\Illuminate\Http\Request $request)
    {
        // validation rule for create request.
        if ($request->isMethod('POST')) {
            return [
                'title'               => 'required',
                'job_type'            => 'required',
                'region'              => 'required',
                'email'               => 'required',
                'details'             => 'required',
                'location'            => 'required',
                'data_posted'         => 'required',
                'salary'              => 'required',
                'status'              => 'required',
                'image'               => 'required',
            ];
        }

        // Validation rule for update request.
        if ($request->isMethod('PUT') || $request->isMethod('PATCH')) {
            return [
                'title'               => 'required',
                'job_type'            => 'required',
                'region'              => 'required',
                'email'               => 'required',
                'details'             => 'required',
                'location'            => 'required',
                'data_posted'         => 'required',
                'salary'              => 'required',
                'status'              => 'required',
                'image'               => 'required',
            ];
        }

        // Default validation rule.
        return [

        ];
    }
}
