<?php

namespace Lavalite\Career\Http\Requests;

use App\Http\Requests\Request;
use User;

class ResumeAdminRequest extends Request
{
    /**
     * Determine if the user is authorized to make this request.
     *
     * @return bool
     */
    public function authorize(\Illuminate\Http\Request $request)
    {
        // Determine if the user is authorized to create an entry,
        if ($request->isMethod('POST') || $request->is('*/create')) {
            return User::can('career.resume.create');
        }

        // Determine if the user is authorized to update an entry,
        if ($request->isMethod('PUT') || $request->isMethod('PATCH') || $request->is('*/edit')) {
            return User::can('career.resume.edit');
        }

        // Determine if the user is authorized to delete an entry,
        if ($request->isMethod('DELETE')) {
            return User::can('career.resume.delete');
        }

        // Determine if the user is authorized to view the module.
        return User::can('career.resume.view');
    }

    /**
     * Get the validation rules that apply to the request.
     *
     * @return array
     */
    public function rules(\Illuminate\Http\Request $request)
    {
        // validation rule for create request.
        if ($request->isMethod('POST')) {
            return [
                'job_id'              => 'required',
                'name'                => 'required',
                'title'               => 'required',
                'video'               => 'required',
                'email'               => 'required',
                'exp_date'            => 'required',
                'category'            => 'required',
                'sub_category'        => 'required',
                'location'            => 'required',
                'skills'              => 'required',
                'content'             => 'required',
                'socialmedias'        => 'required',
                'experience'          => 'required',
                'education'           => 'required',
                'photo'               => 'required',
                'status'              => 'required',
            ];
        }

        // Validation rule for update request.
        if ($request->isMethod('PUT') || $request->isMethod('PATCH')) {
            return [
                'job_id'              => 'required',
                'name'                => 'required',
                'title'               => 'required',
                'video'               => 'required',
                'email'               => 'required',
                'exp_date'            => 'required',
                'category'            => 'required',
                'sub_category'        => 'required',
                'location'            => 'required',
                'skills'              => 'required',
                'content'             => 'required',
                'socialmedias'        => 'required',
                'experience'          => 'required',
                'education'           => 'required',
                'photo'               => 'required',
                'status'              => 'required',
            ];
        }

        // Default validation rule.
        return [

        ];
    }
}
